@@ -1,5 +1,5 @@
 #   fluentmock
-#   Copyright 2013 Michael Gruber
+#   Copyright 2013-2014 Michael Gruber
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.12'
+__version__ = '0.0.13'
 
 
 from mock import patch
@@ -25,11 +25,11 @@ from types import ModuleType
 LOGGER = getLogger(__name__)
 
 
-MESSAGE_COULD_NOT_VERIFY = 'Could not verify {target_name}.{attribute_name}()'
+MESSAGE_COULD_NOT_VERIFY = 'Could not verify {target_name}.{attribute_name}{arguments}'
 MESSAGE_INVALID_ATTRIBUTE = 'The target "{target_name}" has no attribute called "{attribute_name}".'
 MESSAGE_NO_CALLS = """
 Expected: call {target_name}.{attribute_name}()
-     Got: no patched function has been called.
+ but was: no patched function has been called.
 """
 MESSAGE_EXPECTED_BUT_WAS = """
 Expected: {expected}
@@ -246,10 +246,10 @@ class Verifier(FluentTargeting):
                     error_message += '          {call}\n'.format(call=call)
             raise AssertionError(error_message)
 
-        raise AssertionError(self.format_message(MESSAGE_COULD_NOT_VERIFY))
+        raise AssertionError(self.format_message(MESSAGE_COULD_NOT_VERIFY, arguments))
 
-    def format_message(self, message):
-        return message.format(target_name=self._target_name, attribute_name=self._attribute_name)
+    def format_message(self, message, arguments='()'):
+        return message.format(target_name=self._target_name, attribute_name=self._attribute_name, arguments=arguments)
 
 
 class FluentMockException(Exception):
